@@ -29,13 +29,20 @@ class AnalogIO(DwfDevice_SubAPI):
         """Reset and configure all AnalogIO instrument parameters to default values.
 
         If auto-configure is enabled, the changes take immediate effect.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the reset operation.
         """
         result = self.lib.FDwfAnalogIOReset(self.hdwf)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def configure(self) -> None:
-        """Configure the AnalogIO instrument."""
+        """Configure the AnalogIO instrument.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the configure operation.
+        """
         result = self.lib.FDwfAnalogIOConfigure(self.hdwf)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
@@ -45,6 +52,12 @@ class AnalogIO(DwfDevice_SubAPI):
 
         The following status functions will return the information that was read from the device
         when this function was last called.
+
+        Note that this method does not return a value, since the |AnalogIO| functionality is not
+        driven by a state machine.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the status operation.
         """
         result = self.lib.FDwfAnalogIOStatus(self.hdwf)
         if result != RESULT_SUCCESS:
@@ -54,12 +67,22 @@ class AnalogIO(DwfDevice_SubAPI):
         """Verify if Master Enable Setting and/or Master Enable Status are supported for the AnalogIO instrument.
 
         The Master Enable setting is essentially a software switch that "enables" or "turns on" the AnalogIO channels.
-        If supported, the status of this Master Enable switch (Enabled/Disabled) can be queried by calling the
+
+        If supported, the current status of this Master Enable switch (Enabled/Disabled) can be queried by calling the
         :py:meth:`enableStatus` method.
+
+        The Master Enable *status* may be different from the Master Enable *setting* if e.g. an overcurrent protection
+        circuit has been triggered.
+
+        Returns: Tuple[bool, bool]:
+            The elements indicate whether Master Enable 8set* and *status* are supported by the |AnalogIO| device.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         c_set_supported = typespec_ctypes.c_int()
         c_status_supported = typespec_ctypes.c_int()
-        result = self.lib.FDwfAnalogIOEnableInfo(self.hdwf, c_set_supported, c_set_supported)
+        result = self.lib.FDwfAnalogIOEnableInfo(self.hdwf, c_set_supported, c_status_supported)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
         set_supported = bool(c_set_supported.value)
@@ -67,13 +90,29 @@ class AnalogIO(DwfDevice_SubAPI):
         return (set_supported, status_supported)
 
     def enableSet(self, master_enable: bool) -> None:
-        """Set the master enable switch."""
+        """Set the master enable switch.
+
+        Parameters:
+            master_enable (bool): The new value of the Master Enable setting.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         result = self.lib.FDwfAnalogIOEnableSet(self.hdwf, master_enable)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def enableGet(self) -> bool:
-        """Return the current state of the master enable switch. This is not obtained from the device."""
+        """Return the current state of the master enable switch.
+
+        This is not obtained from the device.
+
+        Returns:
+            The value of the Master Enable setting.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_master_enable = typespec_ctypes.c_int()
         result = self.lib.FDwfAnalogIOEnableGet(self.hdwf, c_master_enable)
         if result != RESULT_SUCCESS:
@@ -82,9 +121,17 @@ class AnalogIO(DwfDevice_SubAPI):
         return master_enable
 
     def enableStatus(self) -> bool:
-        """Return the master enable status (if the device supports it).
+        """Return the actual master enable status (if the device supports it).
 
-        This can be a switch on the board or an over-current protection circuit state."""
+        The Master Enable *status* may be different from the Master Enable *setting* if e.g. an overcurrent protection
+        circuit has been triggered.
+
+        Returns:
+            bool: the current status of the Master Enable.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_master_enable_status = typespec_ctypes.c_int()
         result = self.lib.FDwfAnalogIOEnableStatus(self.hdwf, c_master_enable_status)
         if result != RESULT_SUCCESS:
@@ -93,7 +140,14 @@ class AnalogIO(DwfDevice_SubAPI):
         return master_enable_status
 
     def channelCount(self) -> int:
-        """Return the number of AnalogIO channels available on the device."""
+        """Return the number of |AnalogIO| channels available on the device.
+
+        Returns:
+            int: The number of |AnalogIO| channels.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_channel_count = typespec_ctypes.c_int()
         result = self.lib.FDwfAnalogIOChannelCount(self.hdwf, c_channel_count)
         if result != RESULT_SUCCESS:
@@ -102,7 +156,17 @@ class AnalogIO(DwfDevice_SubAPI):
         return channel_count
 
     def channelName(self, channel_index: int) -> Tuple[str, str]:
-        """Return the name (long text) and label (short text, printed on the device) for a channel."""
+        """Return the name (long text) and label (short text, printed on the device) for a channel.
+
+        Parameters:
+            channel_index (int): The channel from which we want to get the name and label.
+
+        Returns:
+            Tuple[str, str]: The name and label of the channel.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_channel_name = ctypes.create_string_buffer(32)
         c_channel_label = ctypes.create_string_buffer(16)
         result = self.lib.FDwfAnalogIOChannelName(
@@ -117,7 +181,17 @@ class AnalogIO(DwfDevice_SubAPI):
         return (channel_name, channel_label)
 
     def channelInfo(self, channel_index: int) -> int:
-        """Return the number of nodes associated with the specified channel."""
+        """Return the number of nodes associated with the specified channel.
+
+        Parameters:
+            channel_index (int): The channel from which we want to get the number of associated nodes.
+
+        Returns:
+            int: The number of nodes associated to the channel.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_node_count = typespec_ctypes.c_int()
         result = self.lib.FDwfAnalogIOChannelInfo(self.hdwf, channel_index, c_node_count)
         if result != RESULT_SUCCESS:
@@ -125,7 +199,18 @@ class AnalogIO(DwfDevice_SubAPI):
         return c_node_count.value
 
     def channelNodeName(self, channel_index: int, node_index: int) -> Tuple[str, str]:
-        """Return the node name ("Voltage", "Current", ...) and units ("V", "A") for an Analog I/O node."""
+        """Return the node name ("Voltage", "Current", …) and units ("V", "A", …) for an |AnalogIO| node.
+
+        Parameters:
+            channel_index (int): The channel from which we want to get the name and unit.
+            node_index (int): The node from which we want to get the name and unit.
+
+        Returns:
+            Tuple[str, str]: The name and unit of the quantity associated with the node.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_node_name = ctypes.create_string_buffer(32)
         c_node_units = ctypes.create_string_buffer(16)
         result = self.lib.FDwfAnalogIOChannelNodeName(
@@ -141,7 +226,18 @@ class AnalogIO(DwfDevice_SubAPI):
         return (node_name, node_units)
 
     def channelNodeInfo(self, channel_index: int, node_index: int) -> DwfAnalogIO:
-        """Return the supported channel node modes."""
+        """Return the supported channel node modes.
+
+        Parameters:
+            channel_index (int): The channel from which we want to get the quantity type.
+            node_index (int): The node from which we want to get the quantity type.
+
+        Returns:
+            DwfAnalogIO: The type of quantity represented by the node.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_analog_io = typespec_ctypes.ANALOGIO()
         result = self.lib.FDwfAnalogIOChannelNodeInfo(
             self.hdwf,
@@ -157,12 +253,20 @@ class AnalogIO(DwfDevice_SubAPI):
         """Return node value limits.
 
         Since a Node can represent many things (Power supply, Temperature sensor, etc.),
-        the Minimum, Maximum, and Steps parameters also represent different types of values.
+        the *minimum*, *maximum*, and *steps* parameters also represent different types of values.
 
-        The (Maximum - Minimum) / Steps is the step size.
-
-        *FDwfAnalogIOChannelNodeInfo* returns the type of values to expect and *FDwfAnalogIOChannelNodeName*
+        :py:meth:`channelNodeInfo` returns the type of values to expect and :py:meth:`channelNodeName`
         returns the units of these values.
+
+        Parameters:
+            channel_index (int): The channel from which we want to get the currently configured value.
+            node_index (int): The node from which we want to get the currently configured value.
+
+        Returns:
+            Tuple[float, float, int]: the minimum and maximum values for the specified node's value, and the number of resolution steps.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
         c_min_value = typespec_ctypes.c_double()
         c_max_value = typespec_ctypes.c_double()
@@ -182,7 +286,15 @@ class AnalogIO(DwfDevice_SubAPI):
         return (min_value, max_value, num_steps)
 
     def channelNodeSet(self, channel_index: int, node_index: int, node_value: float) -> None:
-        """Set the node value for the specified node on the specified channel."""
+        """Set the node value for the specified node on the specified channel.
+
+        Parameters:
+            channel_index (int): The channel from which we want to get the currently configured value.
+            node_index (int): The node from which we want to get the currently configured value.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         result = self.lib.FDwfAnalogIOChannelNodeSet(
             self.hdwf,
             channel_index,
@@ -192,7 +304,15 @@ class AnalogIO(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def channelNodeGet(self, channel_index: int, node_index: int) -> float:
-        """Return the currently set value of the node on the specified channel."""
+        """Return the currently set value of the node on the specified channel.
+
+        Parameters:
+            channel_index (int): The channel from which we want to get the currently configured value.
+            node_index (int): The node from which we want to get the currently configured value.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_node_value = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogIOChannelNodeGet(
             self.hdwf,
@@ -205,7 +325,18 @@ class AnalogIO(DwfDevice_SubAPI):
         return node_value
 
     def channelNodeStatusInfo(self, channel_index: int, node_index: int) -> Tuple[float, float, int]:
-        """Return the range of reading values available for the specified node on the specified channel."""
+        """Return the range of reading values available for the specified node on the specified channel.
+
+        Parameters:
+            channel_index (int): The channel from which we want to get status information.
+            node_index (int): The node from which we want to get status information.
+
+        Returns:
+            Tuple[float, float, int]: the minimum and maximum values for the specified node, and the number of resolution steps.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         c_min_value = typespec_ctypes.c_double()
         c_max_value = typespec_ctypes.c_double()
         c_num_steps = typespec_ctypes.c_int()
@@ -224,14 +355,23 @@ class AnalogIO(DwfDevice_SubAPI):
         return (min_value, max_value, num_steps)
 
     def channelNodeStatus(self, channel_index: int, node_index: int) -> float:
-        """Return the value reading of the node."""
-        c_node_status = typespec_ctypes.c_double()
+        """Return the most recent value reading of the node.
+
+        To fetch updated values for all |AnalogIO| nodes, use the :py:meth:`status` method.
+
+        Returns:
+            float: the most recent value read for this nodes.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
+        c_node_value = typespec_ctypes.c_double()
         result = self.lib.FDwfAnalogIOChannelNodeStatus(
             self.hdwf,
             channel_index,
             node_index,
-            c_node_status)
+            c_node_value)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
-        node_status = c_node_status.value
-        return node_status
+        node_value = c_node_value.value
+        return node_value
