@@ -20,45 +20,87 @@ class DigitalCan(DwfDevice_SubAPI):
     """
 
     def reset(self) -> None:
-        """Reset the digital-CAN protocol instrument."""
+        """Reset the digital-CAN protocol functionality.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the reset operation.
+        """
         result = self.lib.FDwfDigitalCanReset(self.hdwf)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def rateSet(self, data_rate: float) -> None:
-        """Set the CAN data rate, in Hz."""
+        """Set the CAN bus data rate, in Hz.
+
+        Parameters:
+            data_rate (float): The data-rate used by the receiver and transmitter.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         result = self.lib.FDwfDigitalCanRateSet(self.hdwf, data_rate)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
-    def polaritySet(self, high: int) -> None:
-        """Set the polarity."""
-        result = self.lib.FDwfDigitalCanPolaritySet(self.hdwf, high)
+    def polaritySet(self, polarity: bool) -> None:
+        """Set the CAN bus polarity.
+
+        Parameters:
+            polarity (bool): If True, set polarity to *high*.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
+        result = self.lib.FDwfDigitalCanPolaritySet(self.hdwf, int(polarity))
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def txSet(self, channel_index: int) -> None:
-        """Set the TX (outgoing) channel."""
+        """Set the channel where the outgoing (TX) signal will be transmitted.
+
+        Parameters:
+            channel_index (int): The channel (digital pin number) on which to transmit data.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         result = self.lib.FDwfDigitalCanTxSet(self.hdwf, channel_index)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def rxSet(self, channel_index: int) -> None:
-        """Set the RX (incoming) channel."""
+        """Set the channel where the incoming (RX) signal is received.
+
+        Parameters:
+            channel_index (int): The channel (digital pin number) on which to receive data.
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
+        """
         result = self.lib.FDwfDigitalCanRxSet(self.hdwf, channel_index)
         if result != RESULT_SUCCESS:
             raise self.dwf.exception()
 
     def tx(self, v_id: int, extended: bool, remote: bool, data: bytes) -> None:
-        """Transmit outgoing CAN data."""
+        """Transmit outgoing CAN bus data.
+
+        Parameters:
+            v_id (int): (to be documented)
+            extended (bool): (to be documented)
+            remote (bool): (to be documented)
+            data (bytes): Data to be transmitted. Should be at most 8 bytes.
+
+        Raises:
+            PyDwfError: A request to transmit more than 8 bytes was made.
+            DwfLibraryError: There was an error while executing the operation.
+        """
         if len(data) > 8:
             raise PyDwfError("CAN message too long.")
 
-        # We forcefully silence mypy here.
+        # This will be flagged as an error by MyPy.
         #
         # See: https://github.com/sidneycadot/pydwf/issues/10
         #      https://stackoverflow.com/questions/67692907
-
         data_as_uchar_ptr = ctypes.cast(data, typespec_ctypes.c_unsigned_char_ptr)
 
         result = self.lib.FDwfDigitalCanTx(
@@ -74,10 +116,13 @@ class DigitalCan(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def rx(self, size: int = 8) -> Tuple[int, bool, bool, bytes, int]:
-        """Receive incoming CAN data.
+        """Receive incoming CAN bus data.
 
         Returns:
             Tuple[int, bool, bool, bytes, int]: A tuple (vID, extended, remote, data, status)
+
+        Raises:
+            DwfLibraryError: There was an error while executing the operation.
         """
 
         c_vID      = typespec_ctypes.c_int()
