@@ -46,9 +46,10 @@ class DigitalIO(DwfDevice_SubAPI):
             raise self.dwf.exception()
 
     def status(self) -> None:
-        """Read the status and input values, of the device DigitalIO to the PC.
+        """Read the |DigitalIO| status and input values from the device to the PC.
 
-        Note that this method merely performs a status update. No status value is returned.
+        Note that this method does not return a value, since the |DigitalIO| functionality is not driven
+        by a state machine.
 
         Raises:
             DwfLibraryError: There was an error while executing the status operation.
